Command Line Interface
======================
biolexica automatically installs the command :code:`biolexica`. See
:code:`biolexica --help` for usage details.

.. click:: biolexica.cli:main
   :prog: biolexica
   :show-nested:
